-- Install Lazy.nvim
local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)

require('lazy').setup({
    'ConradIrwin/vim-bracketed-paste',
    'airblade/vim-rooter',
    {'cappyzawa/trim.nvim', config = function () require("trim").setup({ ft_blocklist= {"markdown", "vimwiki"}, patterns = { [[%s/\s\+$//e]], [[%s/\($\n\s*\)\+\%$//]], [[%s/\%^\n\+//]], }, }) end},
    {'ggandor/leap.nvim', config = function () require('leap').set_default_keymaps() end},
    'mhartington/formatter.nvim',
    'intrntbrn/awesomewm-vim-tmux-navigator',
    {'numToStr/Comment.nvim', config = function () require('Comment').setup() end},
    'debugloop/telescope-undo.nvim',
    {'vimwiki/vimwiki'},
    {'windwp/nvim-autopairs', setup = function () require('nvim-autopairs').setup({check_ts = true}) require('nvim-autopairs').add_rules(require "nvim-autopairs.rules.endwise-lua")
    end},
    {'lervag/vimtex', ft='latex'},
    {'williamboman/mason-lspconfig.nvim', dependencies = {'williamboman/mason.nvim', 'neovim/nvim-lspconfig'}},
    {"folke/trouble.nvim", dependencies = {"nvim-tree/nvim-web-devicons"}, config = function () require('trouble').setup() end},
    {"nvim-treesitter/nvim-treesitter", build = ":TSUpdate"},
    {"NeogitOrg/neogit", dependencies = {"nvim-lua/plenary.nvim", "nvim-telescope/telescope.nvim", "sindrets/diffview.nvim"}, config = true},
    {'hrsh7th/nvim-cmp', dependencies = {'hrsh7th/cmp-buffer', 'hrsh7th/cmp-cmdline', 'hrsh7th/cmp-nvim-lsp', 'hrsh7th/cmp-path', 'dcampos/nvim-snippy', 'honza/vim-snippets','dcampos/cmp-snippy' }},
    {'nvim-lualine/lualine.nvim', dependencies = { 'nvim-tree/nvim-web-devicons', opt = true }},
    {'nvim-telescope/telescope-fzf-native.nvim', build = 'cmake -S. -Bbuild -DCMAKE_BUILD_TYPE=Release && cmake --build build --config Release && cmake --install build --prefix build' },
    {'nvim-telescope/telescope.nvim', dependencies = {'nvim-lua/plenary.nvim'}},
    {'nvim-tree/nvim-tree.lua', dependencies = {'nvim-tree/nvim-web-devicons'}, tag = 'nightly'},
    {dir = '~/.config/nvim/colorschemes/material', dependencies= {"rktjmp/lush.nvim"}, config = function () vim.cmd("colorscheme material") end},
})
